-- Migrates IRM database from version 3.4 to 3.5

-- Versionning inputs

ALTER TABLE DATA_OBJ_OVRD ADD COLUMN DATA_OBJ_OVRD_VER integer DEFAULT 0;

-- DATA_OBJ_OVRD_VER
--------------------------------------------------------------------------------------------------------

DROP TABLE IF EXISTS DATA_OBJ_OVRD_VER;

CREATE TABLE DATA_OBJ_OVRD_VER
(
   DATA_OBJ_OVRD_VER_KEY SERIAL PRIMARY KEY,
   
   OVRD_VERSION integer NOT NULL,      
   ROOT_PROCESS_KEY bigint NOT NULL,   
   
   SOURCE_PATH character varying(4096) NOT NULL,   
      
   OVRD_URL character varying(2083) NOT NULL,
   OVRD_PATH character varying(4096) NOT NULL,
   OVRD_RAW_PATH character varying(4096),      
               
   MODIFIED_BY character varying(32) NOT NULL,
   MODIFIED_DTTM TIMESTAMP NOT NULL,
   MODIFIED_COMMENTS character varying(255)     
);

ALTER TABLE DATA_OBJ_OVRD_VER ADD CONSTRAINT UNIQUE_OVRD_VER_DATA_ID UNIQUE (OVRD_VERSION, ROOT_PROCESS_KEY, SOURCE_PATH);

 
-- Add MV_NAMES, MV_VALUES column to DATA_OBJ
-- new columns script moved to irmMigrateDB_cond_col_34_35.sql
--alter table DATA_OBJ add column MV_NAMES character varying(255);
--alter table DATA_OBJ add column MV_VALUES character varying(255);


-- DATA_OBJ_REF_RT
--------------------------------------------------------------------------------------------------------
DROP TABLE IF EXISTS DATA_OBJ_REF_RT;

CREATE TABLE DATA_OBJ_REF_RT
(
   DATA_OBJ_REF_RT_KEY SERIAL PRIMARY KEY,  
   DATA_OBJ_REF_KEY bigint NOT NULL,   
   INSTANCE_KEY bigint NOT NULL,      
   RAW_URL character varying(2083)   
);

ALTER TABLE DATA_OBJ_REF_RT ADD CONSTRAINT UNIQUE_DATA_INST_OBJ_REF_RT UNIQUE (DATA_OBJ_REF_KEY, INSTANCE_KEY);


-- Messages for node failures, written to fa.invalid.txt
DROP TABLE IF EXISTS SCA_NODE_MSG;

CREATE TABLE SCA_NODE_MSG
(
   SCA_NODE_MSG_KEY INTEGER NOT NULL,
   FA_ID            VARCHAR(100)  NOT NULL,
   PATH             VARCHAR(1024) NOT NULL,
   MSG              VARCHAR(255)  NOT NULL,
   ORDINAL          INTEGER NOT NULL,
   PRIMARY KEY (SCA_NODE_MSG_KEY)
);

DROP SEQUENCE IF EXISTS SEQ_SCA_NODE_MSG_KEY;
CREATE SEQUENCE SEQ_SCA_NODE_MSG_KEY START WITH 1;

DROP INDEX IF EXISTS SCA_NODE_MSG_IX1;

CREATE INDEX SCA_NODE_MSG_IX1 ON SCA_NODE_MSG (FA_ID,PATH);

-- Node to macro relationship information

-- The nodes
DROP TABLE IF EXISTS SCA_NODE;

CREATE TABLE SCA_NODE
(
   SCA_NODE_KEY INTEGER NOT NULL,
   FA_ID        VARCHAR(100) NOT NULL,
   PATH         VARCHAR(1024) NOT NULL,
   MODIFIED     BIGINT NOT NULL,
   STATUS       INTEGER NOT NULL,
   PRIMARY KEY  (SCA_NODE_KEY)
);

DROP SEQUENCE IF EXISTS SEQ_SCA_NODE_KEY;
CREATE SEQUENCE SEQ_SCA_NODE_KEY START WITH 1;

DROP INDEX IF EXISTS SCA_NODE_IX1;

CREATE UNIQUE INDEX SCA_NODE_IX1 ON SCA_NODE (FA_ID,PATH);

-- The macros
DROP TABLE IF EXISTS SCA_MACRO;

CREATE TABLE SCA_MACRO
(
   SCA_MACRO_KEY      INTEGER NOT NULL,
   FA_ID VARCHAR(100) NOT NULL,
   NAME VARCHAR(32)   NOT NULL,
   PATH VARCHAR(1024) NOT NULL,
   MODIFIED BIGINT    NOT NULL,
   PRIMARY KEY   (SCA_MACRO_KEY)
);

DROP SEQUENCE IF EXISTS SEQ_SCA_MACRO_KEY;
CREATE SEQUENCE SEQ_SCA_MACRO_KEY START WITH 1;

DROP INDEX IF EXISTS SCA_MACRO_IX1;

CREATE UNIQUE INDEX SCA_MACRO_IX1 ON SCA_MACRO (FA_ID,PATH);

-- Macros used by nodes
DROP TABLE IF EXISTS SCA_NODE_MACRO;

CREATE TABLE SCA_NODE_MACRO
(
   SCA_NODE_SK  INTEGER NOT NULL,
   SCA_MACRO_SK INTEGER NOT NULL,
   PRIMARY KEY   (SCA_NODE_SK,SCA_MACRO_SK)
);

ALTER TABLE JOBFLOW_INSTANCE ADD COLUMN AUTORUN_FLG BOOLEAN NOT NULL DEFAULT true;